#
# spec file for package python-JPype1
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  test
# https://build.opensuse.org/package/show/Java:packages/h2database is not in Factory
%bcond_with     test_jdbc
%{?sle15_python_module_pythons}
Name:           python-JPype1
Version:        1.5.1
Release:        1.1
Summary:        Python to Java bridge
License:        Apache-2.0
URL:            https://github.com/jpype-project/jpype
Source:         https://files.pythonhosted.org/packages/source/j/jpype1/jpype1-%{version}.tar.gz
Patch0:         JPype1-java8compat.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  ant
BuildRequires:  ca-certificates-mozilla
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-tools
BuildRequires:  python-rpm-macros
Requires:       java-headless >= 1.8
Recommends:     python-numpy
Suggests:       python-typing_extensions
ExcludeArch:    %{ix86} armv7
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module jedi}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions}
%if %{with test_jdbc}
BuildRequires:  h2database
BuildRequires:  hsqldb
BuildRequires:  sqlite-jdbc
%endif
# /SECTION
%endif
%python_subpackages

%description
A Python to Java bridge.

%prep
%autosetup -p1 -n jpype1-%{version}
# Avoid build dependency on PyInstaller
rm jpype/_pyinstaller/test_jpype_pyinstaller.py

%build
ant -f native/build.xml jar
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
ant -f test/build.xml compile

# JClassTestCase.testAsArray fails on i586
# https://github.com/jpype-project/jpype/issues/1029
skip_tests="(JClassTestCase and testAsArray)"

# v1.4.1: https://github.com/jpype-project/jpype/issues/1116
skip_tests+=" or (HtmlTestCase and testClass)"

%if %{without test_jbdc}
skip_tests+=" or test_sql_h2 or test_sql_hsqldb or test_sql_sqlite"
%endif

export CLASSPATH=${PWD}/test/classes:%{_libdir}/java/sqlite-jdbc.jar:%{_localstatedir}/lib/hsqldb/lib/hsqldb.jar:%{_datadir}/java/h2database/h2.jar:%{_datadir}/java/jts/jts-core.jar:%{_datadir}/java/osgi-service-jdbc/org.osgi.service.jdbc.jar
%pytest_arch -rs -k "not ($skip_tests)"

%endif

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%{python_sitearch}/jpype
%{python_sitearch}/org.jpype.jar
%{python_sitearch}/_jpype*.so
%{python_sitearch}/jpype1-%{version}.dist-info

%changelog
* Sun Nov 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.5.1:
  * Make use of pyproject.toml for static project metadata
  * Fix error in 3.12 during exception handling
  * Changes for numpy 2.0 to fix test matrix.
  * fix compatibility of jpype with setuptools==72.0.0
  * Update LICENSE
  * prevent misuse of PyTuple_Pack
  * Remove use of tp_new
  * fix JUnpickler BufferOverflowException
  * "Generic" JArray support
  * Fix IllegalArgumentException with non-ascii paths
  * Support extracting javadoc HTML files generated by Javadoc 17
  * [ci] allow to download missing Python versions
  * Access to default methods in @JImplements
  * handle non ascii classpath with system classloader
  * free threaded build
- Drop patch JPype1-numpy2compat.patch, included upstream.
* Wed Sep 11 2024 Fergal Mc Carthy <fmccarthy@suse.com>
- Added patch JPype1-numpy2compat.patch to update the test code
  to be numpy 2+ compatible.
- Add a BuildRequires for ca-certificates-mozilla to resolve
  a certificates validation error during wheel creation for
  Tumbleweed builds.
* Thu Aug 22 2024 Aline Werner <aline.werner@suse.com>
- Switch to modern python on sle15.
* Tue Feb 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Support for Python 3.12
  * Switched __eq__ and __ne__ operator to use equals rather than
    compareTo for comparable objects to avoid exception when
    comparing object of different types.
  * Fixed segmentation fault when comparing Java Comparable to
    primitives.
  * Java exceptions that occur in inequality comparisons now map
    to Python TypeError.
  * Fixed crash when calling subscript on JArray.
  * Fixed direct byte buffers not reporting nbytes correctly when
    cast to memoryview.
  * Expand the defintion for Functional interface to include
    classes without FunctionInterface annotation.
  * Add additional matching level for derived types to resolve
    ambiguities when a derived type is used in place of base
    class when determining the method overload.  This will
    resolve some previous ambiguities between methods.
* Mon Jun 12 2023 Fridrich Strba <fstrba@suse.com>
- Do not hardcode java-15-openjdk, since this can be built with
  any Java >= 9
- Added patch:
  * JPype1-java8compat.patch
    + Build packages that are fully backward compatible to Java 8
* Tue Mar  7 2023 John Vandenberg <jayvdb@gmail.com>
- Update to v1.4.1
  * Fixed issue with startJVM changing locale settings
  * Changes to support Python 3.11
  * Fix truncation of strings on null when using convert strings
  * Replaced distutil with packaging
* Thu Aug 18 2022 John Vandenberg <jayvdb@gmail.com>
- ExcludeArch armv7 and i586 due to significant test failures
* Tue Aug 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.4.0
  Support for all different buffer type conversions.
  * Improved buffer transfers to numpy as guaranteed to match Java types.
    However, exact dtype for conversions is os/numpy version dependent.
  * Support for byte order channels on buffer transfers.
  * Byte size for buffers now fixed to Java definitions.
  * When directly accessing Java arrays using memory view, Python requires a cast
    from buffers. Required because Python does not support memory view alterations
    on non-native sizes.
  Fix crash when comparing JChar.
  * Order handling for numerical operations with JChar fixed.
  * Improved matching for Java functors based on parameter count.
  * Dropped support for Python 3.5 and 3.6
  * dbapi2 handles drivers that don't support autocommit.
  * Fixed issue when Java classes with dunder methods such as __del__ caused
    conflicts in Python type system. Java method which match dunder patterns are longer
    translated to Python.
  * Fix issue with numpy arrays with no dimensions resulting in crash.
  * Support for user defined conversions for java.lang.Class and array types.
  * Fixed issue with ssize_t on Windows for Python 3.10.
* Mon Feb 21 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.3.0
  * Fixes for memory issues found when upgrading to Python 3.10 beta.
  * Add additional diagnositics for importing of non-public class.
  * Fixed issue with classes with unsatified dependencies leading to
    a crash on windows.
  * Fixed a bug with arrays created using the short cut.
- from v1.2.1
  * Missing stub files added.
  * Python 3.9 issues are resolved on Windows.
  * JPype scans jar files and rebuilding missing directories to
    allow imports from stripped and obfuscated jar files.
- from v1.2.0
  * Added builds for Python 3.9.
  * Fixed bug when importing from multi-release jars.
  * addClassPath can add jar files after the JVM is started.
    The default loader for JPype class is
    ``org.jpype.classloader.DynamicClassLoader``.
  * Build support of z/OS added.
  * Bug causing ambiguity between primitives and variadic arguments
    in method resolution was corrected.
  * Boolean was inadvertently left out of method resolution.
    ``boolean`` now properly matched with boxed types.
  * Support for PyInstaller was added.
* Tue Apr 27 2021 Markéta Machová <mmachova@suse.com>
- skip python36 because of numpy
* Sat Nov 14 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.1.2
